@@ -14,7 +14,7 @@ from .core import (
     check_hash_line,
     generate_hash_line,
 )
-from .utils.glob import glob_filter
+from .utils.glob import glob_filters
 
 
 class FilePath(click.Path):
@@ -51,20 +51,20 @@ class FilePath(click.Path):
 class Output(object):
     """Determine the output mode and provide the output interface."""
 
-    def __init__(self, sep=None, agg=None, null=None):
-        if (sep and agg) or (sep and null) or (agg and null):
+    def __init__(self, agg=None, sep=None, null=None):
+        if (agg and sep) or (agg and null) or (sep and null):
             raise ValueError("require exactly one argument")
 
         # Use the null mode by default.
-        if not (sep or agg or null):
+        if not (agg or sep or null):
             null = True
 
         # Determine the output mode and dump method.
-        if sep:
-            self._dump = self.output_sep
-        elif agg:
+        if agg:
             self.agg_file = HashFileWriter(agg)
             self._dump = self.output_agg
+        elif sep:
+            self._dump = self.output_sep
         elif null:
             self._dump = self.output_null
 
@@ -79,15 +79,14 @@ class Output(object):
     def dump(self, hash_line, hash_path):
         self._dump(hash_line, hash_path)
 
+    def output_agg(self, hash_line, hash_path):
+        self.agg_file.write_hash_line(hash_line)
+
     def output_sep(self, hash_line, hash_path):
         with HashFileWriter(hash_path) as f:
             f.write_hash_line(hash_line)
 
-    def output_agg(self, hash_line, hash_path):
-        self.agg_file.write_hash_line(hash_line)
-
-    @staticmethod
-    def output_null(hash_line, hash_path):
+    def output_null(self, hash_line, hash_path):
         pass
 
 
@@ -96,39 +95,41 @@ class GetHash(object):
 
     def __init__(self, ctx, **kwargs):
         self.ctx = ctx
+        self.suffix = kwargs.pop("suffix", ".sha")
 
         self.glob_mode = kwargs.pop("glob", 1)
         self.glob_type = kwargs.pop("type", "a")
-        self.suffix = kwargs.pop("suffix", ".sha")
+
+        self.stdout = kwargs.pop("stdout", sys.stdout)
+        self.stderr = kwargs.pop("stderr", sys.stderr)
 
         # Determine the path format.
         self.inplace = kwargs.pop("inplace", False)
         self.root = kwargs.pop("root", None)
 
         # Determine the output mode.
-        sep = kwargs.pop("sep", None)
         agg = kwargs.pop("agg", None)
+        sep = kwargs.pop("sep", None)
         null = kwargs.pop("null", None)
-        self.output = Output(sep, agg, null)
-        self.dump = self.output.dump
-
-        self.stdout = kwargs.pop("stdout", sys.stdout)
-        self.stderr = kwargs.pop("stderr", sys.stderr)
+        self.output = Output(agg, sep, null)
 
         # Prepare arguments and construct the hash function.
-        start = kwargs.pop("start", None)
-        stop = kwargs.pop("stop", None)
-        dir_ok = kwargs.pop("dir", False)
+        self.start = kwargs.pop("start", None)
+        self.stop = kwargs.pop("stop", None)
+        self.dir_ok = kwargs.pop("dir", False)
         tqdm_args = {
             "file": self.stderr,
-            "ascii": kwargs.pop("tqdm-ascii", True),
+            "ascii": kwargs.pop("tqdm-ascii", False),
             "disable": kwargs.pop("tqdm-disable", False),
             "leave": kwargs.pop("tqdm-leave", False),
         }
-        hasher = Hasher(ctx, tqdm_args=tqdm_args)
-        self.hash_function = functools.partial(
-            hasher, start=start, stop=stop, dir_ok=dir_ok
-        )
+        self.hasher = Hasher(ctx, tqdm_args=tqdm_args)
+
+    def __call__(self, check, files):
+        if check:
+            self.check_hash(files)
+        else:
+            self.generate_hash(files)
 
     def echo(self, msg, **kwargs):
         click.secho(msg, file=self.stdout, **kwargs)
@@ -137,6 +138,12 @@ class GetHash(object):
         msg = f"[ERROR] {path}\n\t{type(exc).__name__}: {exc}"
         click.secho(msg, file=self.stderr, fg="red")
 
+    def glob_function(self, pathnames):
+        return glob_filters(pathnames, mode=self.glob_mode, type=self.glob_type)
+
+    def hash_function(self, path):
+        return self.hasher(path, self.start, self.stop, dir_ok=self.dir_ok)
+
     def check_root(self, path):
         if self.inplace:
             return os.path.dirname(path)
@@ -145,12 +152,12 @@ class GetHash(object):
         return None
 
     def generate_hash(self, patterns):
-        for path in glob_filter(patterns, mode=self.glob_mode, type=self.glob_type):
+        for path in self.glob_function(patterns):
             try:
                 root = self.check_root(path)
                 hash_line = generate_hash_line(path, self.hash_function, root=root)
                 hash_path = path + self.suffix
-                self.dump(hash_line, hash_path)
+                self.output.dump(hash_line, hash_path)
             except Exception as e:
                 self.echo_error(path, e)
             else:
@@ -170,9 +177,7 @@ class GetHash(object):
                 self.echo(f"[SUCCESS] {path}", fg="green")
 
     def check_hash(self, patterns):
-        for hash_path in glob_filter(
-            patterns, mode=self.glob_mode, type=self.glob_type
-        ):
+        for hash_path in self.glob_function(patterns):
             try:
                 self._check_hash(hash_path)
             except Exception as e:
@@ -181,12 +186,6 @@ class GetHash(object):
     def close(self):
         self.output.close()
 
-    def __call__(self, check, files):
-        if check:
-            self.check_hash(files)
-        else:
-            self.generate_hash(files)
-
     def __enter__(self):
         return self
 
@@ -197,13 +196,13 @@ class GetHash(object):
 def script_main(ctx, files, **options):
     """Generate the body for the main function."""
 
-    check = options.pop("check", False)
     # Convert bool flags to streams.
     no_stdout = options.pop("no_stdout", False)
     no_stderr = options.pop("no_stderr", False)
     stdout = open(os.devnull, "w") if no_stdout else sys.stdout
     stderr = open(os.devnull, "w") if no_stderr else sys.stderr
 
+    check = options.pop("check", False)
     with GetHash(ctx, stdout=stdout, stderr=stderr, **options) as gh:
         gh(check, files)
 
@@ -216,7 +215,7 @@ def gethashcli(cmdname, hashname, suffix):
             "Path Format", help="Set the path format in checksum files."
         )
         output_mode = MutuallyExclusiveOptionGroup(
-            "Output Mode", help="Ignored when -c is set."
+            "Output Mode", help="Set the file output mode."
         )
 
         @click.command(
@@ -282,7 +281,6 @@ def gethashcli(cmdname, hashname, suffix):
             default=None,
             help="The path field in checksum files is relative to the root directory.",
         )
-        @output_mode.option("-s", "--sep", is_flag=True, help="Separate output files.")
         @output_mode.option(
             "-o",
             "--agg",
@@ -290,6 +288,7 @@ def gethashcli(cmdname, hashname, suffix):
             default=None,
             help="Set the aggregate output file.",
         )
+        @output_mode.option("-s", "--sep", is_flag=True, help="Separate output files.")
         @output_mode.option(
             "-n",
             "--null",
